@@ -87,20 +87,14 @@ def _Viewport_render_image(self, size=(640,480), frame=0, filename=None, backgro
     if len(self.dataset.pipelines) == 0:
         print("Warning: The scene to be rendered is empty. Did you forget to add a pipeline to the scene using Pipeline.add_to_scene()?")
 
-    # Create a target frame buffer for the rendering operation (and display it when running in a gui environment).
-    if ovito.gui:
-        fb = ovito.gui.create_and_show_frame_buffer(rs.output_image_width, rs.output_image_height)
-    else:
-        fb = FrameBuffer(rs.output_image_width, rs.output_image_height)
-
-    # Invoke the actual image rendering function.
-    self.dataset.render_scene(rs, layout, fb)
+    # Invoke the actual image rendering function. It returns a framebuffer object.
+    fb = self.dataset.render_scene(rs, layout)
 
     # Crop away background pixels along the outer edges of the image if requested.
     if crop:
         fb.auto_crop()
 
-    # Get the rendered image.
+    # Extract the QImage, which is the backing store of the framebuffer.
     img = fb.image
 
     # Save image to the output file if requested.
@@ -169,13 +163,7 @@ def _Viewport_render_anim(self, filename, size=(640,480), fps=10, background=(1.
     if len(self.dataset.pipelines) == 0:
         print("Warning: The scene to be rendered is empty. Did you forget to add a pipeline to the scene using Pipeline.add_to_scene()?")
 
-    # Create a target frame buffer for the rendering operation (and display it when running in a gui environment).
-    if ovito.gui:
-        fb = ovito.gui.create_and_show_frame_buffer(rs.output_image_width, rs.output_image_height)
-    else:
-        fb = FrameBuffer(rs.output_image_width, rs.output_image_height)
-
-    self.dataset.render_scene(rs, layout, fb)
+    self.dataset.render_scene(rs, layout)
 Viewport.render_anim = _Viewport_render_anim
 
 # Here only for backward compatibility with OVITO 2.9.0:
@@ -194,14 +182,12 @@ def _Viewport_render(self, settings = None):
     if len(self.dataset.pipelines) == 0:
         print("Warning: The scene to be rendered is empty. Did you forget to add a pipeline to the scene using Pipeline.add_to_scene()?")
 
-    # Create a target frame buffer for the rendering operation (and display it when running in a gui environment).
-    if ovito.gui:
-        fb = ovito.gui.create_and_show_frame_buffer(settings.output_image_width, settings.output_image_height)
-    else:
-        fb = FrameBuffer(settings.output_image_width, settings.output_image_height)
-
     layout = [(self, (0.0, 0.0, 1.0, 1.0))]
-    self.dataset.render_scene(settings, layout, fb)
+
+    # Perform the actual rendering operation.
+    fb = self.dataset.render_scene(settings, layout)
+
+    # Extract the QImage backing store from the framebuffer.
     return fb.image
 Viewport.render = _Viewport_render
 
